<?php
require_once(__DIR__ . '/../inc/config.php');

$wrong_pass = 0;

// set referrer
$referrer = (isset($_SERVER['HTTP_REFERER'])) ? $_SERVER['HTTP_REFERER'] : '';

// check if is unlogged user redirected from select plan page
$frags = '';

if(!empty($_SERVER['PATH_INFO'])) {
	$frags = $_SERVER['PATH_INFO'];
}
else {
	if(!empty($_SERVER['ORIG_PATH_INFO'])) {
		$frags = $_SERVER['ORIG_PATH_INFO'];
	}
}

$frags   = explode("/", $frags);
$from = (!empty($frags[1])) ? $frags[1] : '';
if(!empty($from)) {
	$referrer = $baseurl . '/user/select-plan';
}

// if page requested by submitting login form
if(isset($_POST['email']) && isset($_POST['password'])) {
	$email    = $_POST['email'];
	$password = $_POST['password'];
	$referrer = $_POST['referrer'];

	// trim
	$email    = trim($email);
	$password = trim($password);
	$referrer = trim($referrer);

	$ignore_referrer = array('password-request', 'logoff', 'sign-up', 'login', 'password-reset', 'signup-confirm');

	foreach($ignore_referrer as $v) {
		$pos = strpos($referrer, $v);
		if($pos !== false) {
			$referrer = $baseurl;
		}
	}

	$stmt = $conn->prepare("SELECT id, password FROM users WHERE email = :email");
	$stmt->bindValue(':email', $email);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$userid          = $row['id'];
	$password_hashed = $row['password'];

	// user exist?
	if(password_verify($password, $password_hashed)) {
		// generate random token
		$token = bin2hex(openssl_random_pseudo_bytes(16));

		// set cookie, provider is current site
		// signature: setcookie(name, value, expire, path, domain, secure, httponly);
		$cookie_val = "$userid-localhost-$token";
		setcookie('loggedin', $cookie_val, time()+86400*30, $install_path, '', '', true);

		// record tokens in db
		record_tokens($userid, 'localhost', $token);

		// start session
		$_SESSION['user_connected'] = true;
		$_SESSION['userid'] = $userid;

		if(!empty($referrer)) {
			header("Location: $referrer");
		}
		else {
			header("Location: $baseurl");
		}
	}

	// wrong email or password?
	else {
		$wrong_pass = 1;
	}
} // end if isset($_POST['email']) && isset($_POST['password'])

// else, if login page request by clicking a provider button
if(isset($_GET['provider'])) {
	// vars
	$email_already_used = 0;

	// the selected provider
	$provider_name = $_GET['provider'];
	$referrer = (isset($_GET['referrer'])) ? $_GET['referrer'] : '';

	// include HybridAuth library
	$config = __DIR__ . '/../vendor/hybridauth/hybridauth/hybridauth/config.php';

	try {
		// initialize Hybrid_Auth class with the config file
		$hybridauth = new Hybrid_Auth($config);

		// try to authenticate with the selected provider
		$adapter = $hybridauth->authenticate($provider_name);

		// then grab the user profile
		$user_profile = $adapter->getUserProfile();
	}

	// something went wrong?
	catch( Exception $e ) {
		header("Location: $baseurl/_msg.php?msg=hybrid_auth_problem");
	}

	$provider_user_id = $user_profile->identifier;
	$first_name       = $user_profile->firstName;
	$last_name        = $user_profile->lastName;
	$email            = (isset($user_profile->email)) ? $user_profile->email : $provider_user_id;

	// check if social login email has already been used to create a local account on the site
	$stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE email = :email AND hybridauth_provider_name = 'local'");
	$stmt->bindValue(':email', $email);
	$stmt->execute();
	$count = $stmt->fetchColumn();

	if($count > 0) {
		$email_already_used = 1;
	}

	// social login email was never used to create a local account
	if($email_already_used == 0) {
		// check if the current user already have authenticated using this provider before
		$stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE hybridauth_provider_name = :provider_name AND hybridauth_provider_uid = :provider_user_id");
		$stmt->bindValue(':provider_name', $provider_name);
		$stmt->bindValue(':provider_user_id', $provider_user_id);
		$stmt->execute();
		$count = $stmt->fetchColumn();

		// if the user didn't authenticate using the selected provider before
		// we create a new entry on database.users for him
		if($count < 1) {
			// generate a random password
			$password = generatePassword();
			$password_hashed = password_hash($password, PASSWORD_BCRYPT);

			$stmt = $conn->prepare('
			INSERT INTO users(
				email,
				password,
				first_name,
				last_name,
				hybridauth_provider_name,
				hybridauth_provider_uid,
				created,
				status
				)
			VALUES(
				:email,
				:password,
				:first_name,
				:last_name,
				:hybridauth_provider_name,
				:hybridauth_provider_uid,
				NOW(),
				:status
				)
			');

			$stmt->bindValue(':email'                   , $email);
			$stmt->bindValue(':password'                , $password_hashed);
			$stmt->bindValue(':first_name'              , $first_name);
			$stmt->bindValue(':last_name'               , $last_name);
			$stmt->bindValue(':hybridauth_provider_name', $provider_name);
			$stmt->bindValue(':hybridauth_provider_uid' , $provider_user_id);
			$stmt->bindValue(':status'                  , 'approved');
			$stmt->execute();

			// get the id of the user that we've just created
			$stmt = $conn->prepare("SELECT id FROM users WHERE email = :email AND password = :password");
			$stmt->bindValue(':email', $email);
			$stmt->bindValue(':password', $password_hashed);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$userid = $row['id'];

			// save profile picture if exists
			// check if there is a picture
			$url = (isset($user_profile->photoURL)) ? $user_profile->photoURL : '';

			if(!empty($url)) {
				// effective url using curl
				$ch = curl_init();
				curl_setopt($ch, CURLOPT_URL, $url);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
				curl_setopt($ch, CURLOPT_HEADER, 1);
				curl_setopt($ch, CURLOPT_NOBODY, 1);
				curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

				// Execute
				curl_exec($ch);

				// get picture info
				if(!curl_errno($ch)) {
					$info = curl_getinfo($ch);
					$effective_url = $info['url'];
					$content_type = $info['content_type'];
					$http_code = $info['http_code'];
				}

				// Close handle
				curl_close($ch);

				// file extension
				$extension = '';
				if($content_type == 'image/gif') {
					$extension = 'gif';
				}
				if($content_type == 'image/jpeg') {
					$extension = 'jpg';
				}
				if($content_type == 'image/png') {
					$extension = 'png';
				}

				if(!empty($extension)) {
					// create pic dir
					$folder = ceil($userid / 1000) + 1;

					if(strlen($folder) < 1) {
						$folder = '999';
					}

					// create path
					$path = __DIR__ . '/profile_pic/' . $folder;

					if (!is_dir($path)) {
						mkdir($path, 0777, true);
					}

					$path = $path . '/' . $userid . '.' . $extension;

					// dir created, now curl pic
					$headers = getHeaders($effective_url);
					// print_r2($headers);

					if(download($effective_url, $path)) {
						// echo 'Download complete!';
					}
				}
			}
			else {
				echo 'empty';
			}
		}

		// user have already authenticated with this provider and is already registered. Get userid
		else {
			$stmt = $conn->prepare("SELECT id FROM users WHERE hybridauth_provider_name = :provider_name AND hybridauth_provider_uid = :provider_user_id");
			$stmt->bindValue(':provider_name', $provider_name);
			$stmt->bindValue(':provider_user_id', $provider_user_id);
			$stmt->execute();
			$row = $stmt->fetch(PDO::FETCH_ASSOC);
			$userid = $row['id'];
		}

		// create token
		$token = bin2hex(openssl_random_pseudo_bytes(16));

		// record tokens
		record_tokens($userid, $provider_name, $token);

		// set session vars
		$_SESSION['user_connected'] = true;
		$_SESSION['userid'] = $userid;

		// set cookie
		$cookie_val = "$userid-$provider_name-$token";
		setcookie('loggedin', $cookie_val, time()+86400*30, $install_path, '', '', true);

		// redirect
		$ignore_referrer = array('password-request', 'logoff', 'sign-up', 'login', 'user', 'admin');

		foreach($ignore_referrer as $v) {
			$pos = strpos($referrer, $v);
			if($pos !== false) {
				$referrer = $baseurl;
			}
		}

		if(!empty($referrer)) {
			header("Location: $referrer");
		}
		else {
			header("Location: $baseurl");
		}
	} // if($email_already_used == 0)
} // end if(isset($_GET['provider']))



// if just loading the page, include the login box template
// template file
require_once(__DIR__ . '/../templates/user_templates/tpl_login.php');